KW_JTI = 'jti'
KW_CLAIMS = 'user_claims'
KW_IDENTITY = 'identity'
KW_FRESH = 'fresh'
KW_EXPIRATION = 'exp'
KW_NFB = 'nbf'
KW_IAT = 'iat'
KW_TYPE = 'type'

KW_JWT_SECRET_KEY = 'JWT_SECRET_KEY'
KW_JWT_BLACKLIST_ENABLED = 'JWT_BLACKLIST_ENABLED'

UNAUTHORIZED_MESSAGE = 'Unauthorized'
FORBIDDEN_MESSAGE = 'Frobidden'

KW_CONTEXT = 'context'
KW_DATA = 'data'


ACCESS_VALUE_TYPE = 'access'
REFRESH_VALUE_TYPE = 'refresh'


JWT_HEADER_NAME = 'JWT_HEADER_NAME'
JWT_HEADER_TYPE = 'JWT_HEADER_TYPE'
DEFAULT_JWT_AUTHORIZATION_HEADER_NAME = "Authorization"
DEFAULT_JWT_AUTHORIZATION_HEADER_TYPE = "Bearer"

DEFAULT_JWT_SESSION_ALGORITHM = "HS256" ###- HS512
DEFAULT_JWT_SESSION_HEADER_NAME = "Context"
DEFAULT_JWT_SESSION_HEADER_TYPE = "Bearer"
